@@ -45,7 +45,5 @@ class CDARequest(object):
         return self._envelope
 
     def to_string(self) -> bytes:
-        """
-        Returns the SOAP request as a string encoded in cp850 (bytes).
-        """
+        """Returns the SOAP request as a string encoded in cp850 (bytes)."""
         return etree.tostring(self._envelope, encoding='cp850', xml_declaration=True)
