@@ -1,7 +1,7 @@
 from typing import Any, Optional
 
 from lxml import etree
-from pydantic import BaseModel, Extra
+from pydantic import BaseModel, ConfigDict
 
 from spei.types import CategoriaOrdenPago
 
@@ -11,9 +11,7 @@ class Mensaje(BaseModel):
     ordenpago: Optional[Any] = None
     respuesta: Optional[Any] = None
     ensesion: Optional[Any] = None
-
-    class Config:  # noqa: WPS306, WPS431
-        extra = Extra.allow
+    model_config = ConfigDict(extra='allow')
 
     @classmethod
     def parse_xml(cls, mensaje: bytes):  # noqa: WPS210
