@@ -6,13 +6,12 @@ from lxml.etree import _Element  # noqa: WPS450, WPS458
 from pydantic import BaseModel, ConfigDict, field_validator
 
 from spei import types
-from spei.resources.validators import validate_alphanumeric
-from spei.types.common import DateInt, InstitutionCode
+from spei.resources.validators import normalize_invalid_chars
 from spei.utils import to_camel_case, to_pascal_case, to_snake_case  # noqa: WPS347
 
 SOAP_NS = 'http://schemas.xmlsoap.org/soap/envelope/'
 PRAXIS_NS = 'http://www.praxis.com.mx/'
-_WHITESPACE_PATTERN = re.compile(r'\s+')
+_DATE_PATTERN = re.compile(r'^\d{4}(0[1-9]|1[0-2])(0[1-9]|[12][0-9]|3[01])$')
 _CAMEL_CASE_FIELDS = frozenset(
     (
         'op_rastreo_ori',
@@ -177,7 +176,7 @@ class Orden(BaseModel):
                     subelement.text = str(value)
                     continue
 
-                text = self._process_text(str(value), element)
+                text = normalize_invalid_chars(str(value))
 
                 if element in _CAMEL_CASE_FIELDS:
                     subelement = etree.SubElement(
@@ -223,7 +222,7 @@ class Orden(BaseModel):
             return
 
         tag = to_snake_case(element.tag)
-        stripped = _WHITESPACE_PATTERN.sub(' ', element.text.strip())
+        stripped = element.text.strip()
 
         if tag == 'op_ins_clave':
             orden_data['op_ins_clave_ord'] = stripped
@@ -233,13 +232,5 @@ class Orden(BaseModel):
             orden_data['op_firma_dig'] = stripped
             return
 
-        if tag in cls.model_fields:
-            orden_data[tag] = cls._process_text(stripped, tag)
-
-    @classmethod
-    def _process_text(cls, text: str, tag: str) -> Optional[str]:
-        """Process and validate the text content of an XML element."""
-        try:
-            return validate_alphanumeric(text)
-        except ValueError as error:
-            raise ValueError(f'{error} in {tag}') from error
+        if tag in cls.__fields__:
+            orden_data[tag] = stripped
