@@ -29,9 +29,9 @@ class Respuesta(BaseModel):
         respuesta = etree.Element('respuesta')
 
         for element, value in self.dict(exclude={'categoria'}).items():  # noqa: WPS110
-            if element in self.model_fields:
-                upper_camel_case_element = to_pascal_case(element)
-                subelement = etree.SubElement(respuesta, upper_camel_case_element)
+            if element in self.__fields__:
+                pascal_case_element = to_pascal_case(element)
+                subelement = etree.SubElement(respuesta, pascal_case_element)
                 subelement.text = str(value)
 
         return respuesta
